/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { Blob, constructHeaders, executeHttpCall, FormData, Request } from '@managed-api/commons-core';
import { FieldTypeOptions, getVersion, MethodTypeOptions } from './definitions/typeOptions';
import { customErrorHandlers, errorStrategyBuilderConstructor } from './errorStrategy';
import { mutation as buildMutation, query as buildQuery } from 'gql-query-builder';
export async function errorMessageBuilder(response, reason) {
    try {
        const error = await response.json();
        const errorMessages = error.errors.map((err) => err.message);
        if (errorMessages.length > 0) {
            return `${reason} - ${errorMessages.join(', ')}`;
        }
    }
    catch { }
    return reason;
}
export const getGraphQLOperation = (operation, operationTypeInfo, operationFields, operationArguments, operationFragments, path = '') => {
    const operationTypeOptions = operationTypeInfo === null || operationTypeInfo === void 0 ? void 0 : operationTypeInfo[operation];
    const operationTypeOptionsArguments = operationTypeOptions === null || operationTypeOptions === void 0 ? void 0 : operationTypeOptions.args;
    const operationTypeOptionsFields = operationTypeOptions === null || operationTypeOptions === void 0 ? void 0 : operationTypeOptions.fields;
    const newTypeInfo = operationTypeOptionsFields ? FieldTypeOptions[operationTypeOptionsFields] : undefined;
    const newPathStart = path === '' ? path : `${path}_`;
    // Get graphQL variables
    const variables = operationArguments ? Object.entries(operationArguments).reduce((acc, [argumentKey, argumentValue]) => {
        var _a;
        const newPath = `${newPathStart}${argumentKey}`;
        const argumentBase = (_a = operationTypeOptionsArguments === null || operationTypeOptionsArguments === void 0 ? void 0 : operationTypeOptionsArguments[argumentKey]) !== null && _a !== void 0 ? _a : {};
        if (['column_values', 'defaults', 'value', 'config'].includes(argumentKey) && typeof argumentValue === 'object') {
            acc[newPath] = { ...argumentBase, value: JSON.stringify(argumentValue), name: argumentKey };
        }
        else if (Array.isArray(argumentValue)) {
            acc[newPath] = { ...argumentBase, list: true, value: argumentValue, name: argumentKey };
        }
        else {
            acc[newPath] = { ...argumentBase, value: argumentValue, name: argumentKey };
        }
        return acc;
    }, {}) : undefined;
    // Get graphQL fields
    const fields = getGraphQLFields(operationFields, newPathStart, newTypeInfo);
    // Get graphQL fragment fields
    if (operationFragments) {
        Object.entries(operationFragments).forEach(operationFragment => {
            if (operationFragment[1]) {
                const fragmentFields = getGraphQLFields(operationFragment[1], newPathStart, newTypeInfo);
                // Add fragment to fields
                fields.push({
                    operation: operationFragment[0],
                    fields: fragmentFields,
                    fragment: true,
                });
            }
        });
    }
    return {
        operation,
        variables,
        fields
    };
};
function getGraphQLFields(operationFields, newPathStart, newTypeInfo) {
    return Object.entries(operationFields).map(([fieldKey, fieldValue]) => {
        if (typeof fieldValue == 'boolean') {
            if (fieldValue) {
                return fieldKey;
            }
            return undefined;
        }
        if (fieldValue === undefined) {
            return undefined;
        }
        const newPath = `${newPathStart}${fieldKey}`;
        return getGraphQLOperation(fieldKey, newTypeInfo, fieldValue.fields, fieldValue.args, fieldValue.fragments, newPath);
    }).filter((field) => !!field);
}
export const constructUploadFilePayload = async (mutation, implementation, args, fields, complexity) => {
    const complexityFieldsToFetchArray = extractComplexityFields(complexity);
    const complexityFragment = complexityFieldsToFetchArray.length > 0
        ? ` complexity {${complexityFieldsToFetchArray}}`
        : '';
    const query = mutation === 'add_file_to_update' ?
        `mutation ($file: File!) { add_file_to_update (update_id: ${args.update_id}, file: $file) {${Object.keys(fields).join(' ')}} ${complexityFragment} }` :
        `mutation ($file: File!) { add_file_to_column (item_id: ${args.item_id}, column_id: "${args.column_id}", file: $file) {${Object.keys(fields).join(' ')}} ${complexityFragment} }`;
    const variables = mutation === 'add_file_to_update' ? { updateId: args.update_id } : { columnId: args.column_id, itemId: args.item_id };
    const map = { file: 'variables.file' };
    const upfile = `./${args.file.fileName}`;
    const form = new FormData();
    form.setBufferImplementation(implementation);
    form.append('query', query, '');
    form.append('variables', JSON.stringify(variables), '');
    form.append('map', JSON.stringify(map), '');
    form.append('file', new Blob(implementation, [args.file.content], {}), upfile);
    return form.getBlob();
};
export const createQuery = async (options, queryName, implementation, getGlobalErrorStrategy) => {
    const { errorStrategy, fields, args, complexity, fragments } = options;
    const version = getVersion();
    const updatedHeaders = updateHeadersWithVersion(options, version);
    const newFields = getGraphQLOperation(queryName, MethodTypeOptions, fields, args, fragments, '');
    const query = buildQuery(injectComplexityIntoQraphQLOperation(newFields, complexity));
    const body = JSON.stringify(query);
    const request = new Request('POST', '/v2', constructHeaders(body, updatedHeaders), body);
    request.setBufferImplementation(implementation);
    return await executeHttpCall(implementation, request, errorStrategyBuilderConstructor, getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
};
export const createMutation = async (options, mutation, implementation, getGlobalErrorStrategy) => {
    const { errorStrategy, fields, args, complexity, fragments } = options;
    const version = getVersion();
    const updatedHeaders = updateHeadersWithVersion(options, version);
    const newFields = getGraphQLOperation(mutation, MethodTypeOptions, fields, args, fragments, '');
    const query = buildMutation(injectComplexityIntoQraphQLOperation(newFields, complexity));
    const body = JSON.stringify(query);
    const request = new Request('POST', '/v2', constructHeaders(body, updatedHeaders), body);
    request.setBufferImplementation(implementation);
    return await executeHttpCall(implementation, request, errorStrategyBuilderConstructor, getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
};
export const updateHeadersWithVersion = (options, version) => {
    const newHeaders = { ...options.headers, 'API-Version': version };
    return newHeaders;
};
const injectComplexityIntoQraphQLOperation = (operation, complexity) => {
    const complexityFieldsArray = extractComplexityFields(complexity);
    if (!complexity || complexityFieldsArray.length === 0) {
        return operation;
    }
    else {
        return [{
                ...operation
            }, {
                operation: 'complexity',
                fields: complexityFieldsArray,
                variables: undefined
            }];
    }
};
/**
 * Convert the complexity options, from type ComplexityFields to a string[] list of all the complexity attributes we want to fetch
 * @param complexity
 */
const extractComplexityFields = (complexity) => {
    return complexity ?
        Object.entries(complexity).map(([fieldKey, fieldValue]) => {
            if (typeof fieldValue === 'boolean') {
                if (fieldValue) {
                    return fieldKey;
                }
            }
        }).filter((field) => !!field)
        : [];
};
