/*!
 * Copyright Adaptavist 2023 (c) All rights reserved
 */
import { ErrorStrategyOption } from '../errorStrategy';
import { HeadersOption } from '@managed-api/commons-core';
import { BoardReturnType, BoardFields, SelectBoardReturnType, BoardKind, BoardsOrderBy, BoardAttributes } from '../definitions/board';
import { BoardDuplicationFields, BoardDuplicationReturnType, SelectBoardDuplicationReturnType } from '../definitions/boardDuplication';
import { UpdateBoardReturnType } from '../definitions/updateBoard';
import { SelectUserReturnType, UserFields, UserReturnType } from '../definitions/user';
import { BoardViewsFields, SelectBoardViewsReturnType } from '../definitions/boardViews';
import { BoardGroupFields, BoardGroupReturnType, GroupAttributes, GroupColorHexCodes, GroupColors, PositionRelative, SelectBoardGroupReturnType } from '../definitions/group';
import { BoardGroupsFields } from '../definitions/groups';
import { State } from '../definitions/state';
import { ComplexityFields, ComplexityOption, ComplexityReturnType } from '../definitions/complexity';
export interface GetBoardsRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args?: {
        /**
         * The board's kind (public / private / share)
         */
        board_kind?: BoardKind;
        /**
         * A list of boards unique identifiers.
         */
        ids?: number[];
        /**
         * Number of items to get, the default is 25.
         */
        limit?: number;
        /**
         * Property to order by (created_at / used_at).
         */
        order_by?: BoardsOrderBy;
        /**
         * Page number to get, starting at 1.
         */
        page?: number;
        /**
         * The state of the board (all / active / archived / deleted), the default is active.
         */
        state?: State;
        /**
         * A list of workspace ids the boards are contained in.
         */
        workspace_ids?: number[];
    };
    fields: BoardFields;
    complexity?: ComplexityFields;
}
export interface GetBoardsResponseOK<S extends GetBoardsRequest = GetBoardsRequest> {
    data: {
        boards: Array<SelectBoardReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetBoardsFullResponseOK {
    data: {
        boards: BoardReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateBoardGroupRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier.
         */
        board_id: number;
        /**
         * The new group's name.
         */
        group_name: string;
        /**
         * The unique identifier of the group you want to create the new one in relation to. The default creates the new group below the specified group_id.
         *
         * You can also use this argument in conjunction with position_relative_group to specify if you want to create the new group above or below the group in question.
         */
        relative_to?: string;
        /**
         * You can use this argument in conjunction with relative_to to specify which group you want to create the new group above or below.
         *
         * - before_at: This enum value creates the new group above the relative_to value. If you don't use the relative_to argument, the new group will be created at the bottom of the board.
         * - after_at: This enum value creates the new group below the relative_to value. If you don't use the relative_to argument, the new group will be created at the top of the board.
         */
        position_relative_method?: PositionRelative | null;
        /**
         * The group's HEX code color. Please note that this argument is only available in API versions 2024-04 and later.
         */
        group_color?: GroupColorHexCodes;
    };
    fields: BoardGroupFields;
    complexity?: ComplexityFields;
}
export interface DeleteBoardGroupRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The group's unique identifier.
         */
        group_id: string;
        /**
         * The board's unique identifier.
         */
        board_id: number;
    };
    fields: BoardGroupFields;
    complexity?: ComplexityFields;
}
export interface ArchiveBoardGroupRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The group's unique identifier.
         */
        group_id: string;
        /**
         * The board's unique identifier.
         */
        board_id: number;
    };
    fields: BoardGroupFields;
    complexity?: ComplexityFields;
}
export interface DuplicateBoardGroupRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier.
         */
        board_id: number;
        /**
         * The group's unique identifier.
         */
        group_id: string;
        /**
         * Boolean to add the new group to the top of the board.
         */
        add_to_top?: boolean;
        /**
         * The group's title.
         */
        group_title?: string;
    };
    fields: BoardGroupFields;
    complexity?: ComplexityFields;
}
export interface UpdateBoardGroupRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier.
         */
        board_id: number;
        /**
         * The group's unique identifier.
         */
        group_id: string;
        /**
         * The new attribute value.
         * For a list of valid color values, use GroupColors enum
         *
         * When updating a group's position using the relative_position_after or relative_position_before attributes, the new attribute value should be the unique identifier (group id) of the group you intend to place the updated group above or below.
         *
         */
        new_value: string | GroupColors;
        /**
         * The group attribute that you want to update.
         * The accepted attributes are title, color, position (DEPRECATED), relative_position_after, and relative_position_before.
         * Use the GroupAttributes enum for a list of valid values
         */
        group_attribute: GroupAttributes;
    };
    fields: BoardGroupFields;
    complexity?: ComplexityFields;
}
export interface CreateBoardRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's name
         */
        board_name: string;
        /**
         * Optional board's description
         */
        description?: string;
        /**
         * The board's kind (public / private / share)
         */
        board_kind: BoardKind;
        /**
         * Optional board folder id
         */
        folder_id?: number;
        /**
         * Optional workspace id
         */
        workspace_id?: number;
        /**
         * Optional board template id
         */
        template_id?: number;
        /**
         * Optional board owner ids
         */
        board_owner_ids?: number[];
        /**
         * Optional board subscriber ids
         */
        board_subscriber_ids?: number[];
        /**
         * Optional list of subscriber team ids
         */
        board_subscriber_teams_ids?: number[];
    };
    fields: BoardFields;
    complexity?: ComplexityFields;
}
export interface CreateBoardResponseOK<S extends CreateBoardRequest> {
    data: {
        create_board: SelectBoardReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateBoardFullResponseOK {
    data: {
        create_board: BoardReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DuplicateBoardRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier.
         */
        board_id: number;
        /**
         * The duplicated board's name. If omitted, it will be automatically generated.
         */
        board_name?: string;
        /**
         * The duplication type: duplicate_board_with_structure, duplicate_board_with_pulses, or duplicate_board_with_pulses_and_updates.
         */
        duplicate_type: 'duplicate_board_with_structure' | 'duplicate_board_with_pulses' | 'duplicate_board_with_pulses_and_updates';
        /**
         * The destination folder within the destination workspace. The folder_id is required if you are duplicating to another workspace, otherwise, it is optional. If omitted, it will default to the original board's folder.
         */
        folder_id?: number;
        /**
         * The destination workspace. If omitted, it will default to the original board's workspace.
         */
        workspace_id?: number;
        /**
         * Ability to duplicate the subscribers to the new board. Defaults to false.
         */
        keep_subscribers?: boolean;
    };
    fields: BoardDuplicationFields;
    complexity?: ComplexityFields;
}
export interface DuplicateBoardResponseOK<S extends DuplicateBoardRequest> {
    data: {
        duplicate_board: SelectBoardDuplicationReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DuplicateBoardFullResponseOK {
    data: {
        duplicate_board: BoardDuplicationReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface UpdateBoardRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         *The board's unique identifier
         */
        board_id: number;
        /**
         * The board's attribute to update (name / description / communication)
         */
        board_attribute: BoardAttributes;
        /**
         * The new attribute value.
         */
        new_value: string;
    };
    complexity?: ComplexityFields;
}
export interface UpdateBoardResponseOK {
    data: {
        update_board: string;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface UpdateBoardFullResponseOK {
    data: {
        update_board: UpdateBoardReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ArchiveBoardRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier
         */
        board_id: number;
    };
    fields: BoardFields;
    complexity?: ComplexityFields;
}
export interface ArchiveBoardResponseOK<S extends ArchiveBoardRequest> {
    data: {
        archive_board: SelectBoardReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ArchiveBoardFullResponseOK {
    data: {
        archive_board: BoardReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteBoardRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier
         */
        board_id: number;
    };
    fields: BoardFields;
    complexity?: ComplexityFields;
}
export interface DeleteBoardResponseOK<S extends DeleteBoardRequest> {
    data: {
        delete_board: SelectBoardReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteBoardFullResponseOK {
    data: {
        delete_board: BoardReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteSubscribersBoardRequest extends HeadersOption, ErrorStrategyOption, ComplexityOption {
    args: {
        /**
         * The board's unique identifier
         */
        board_id: number;
        /**
         * User ids to unsubscribe from a board
         */
        user_ids: number[];
    };
    fields: UserFields;
    complexity?: ComplexityFields;
}
export interface DeleteSubscribersBoardResponseOK<S extends DeleteSubscribersBoardRequest> {
    data: {
        delete_subscribers_from_board: Array<SelectUserReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteSubscribersBoardFullResponseOK {
    data: {
        delete_subscribers_from_board: UserReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetBoardViewsRequest extends GetBoardsRequest {
    fields: BoardViewsFields;
    complexity?: ComplexityFields;
}
export interface GetBoardGroupsRequest extends GetBoardsRequest {
    fields: BoardGroupsFields;
}
export interface GetBoardViewsResponseOK<S extends GetBoardViewsRequest = GetBoardViewsRequest> {
    data: {
        boards: Array<SelectBoardViewsReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetBoardViewsFullResponseOK {
    data: {
        boards: BoardReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetBoardGroupsResponseOK<S extends GetBoardGroupsRequest = GetBoardGroupsRequest> {
    data: {
        boards: Array<SelectBoardGroupReturnType<S['fields']>>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface GetBoardGroupsFullResponseOK {
    data: {
        boards: BoardGroupReturnType[];
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateBoardGroupResponseOK<S extends CreateBoardGroupRequest> {
    data: {
        create_group: SelectBoardGroupReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface CreateBoardGroupFullResponseOK {
    data: {
        create_group: BoardGroupReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteBoardGroupResponseOK<S extends DeleteBoardGroupRequest> {
    data: {
        delete_group: SelectBoardGroupReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DeleteBoardGroupFullResponseOK {
    data: {
        delete_group: BoardGroupReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ArchiveBoardGroupResponseOK<S extends ArchiveBoardGroupRequest> {
    data: {
        archive_group: SelectBoardGroupReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface ArchiveBoardGroupFullResponseOK {
    data: {
        archive_group: BoardGroupReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DuplicateBoardGroupResponseOK<S extends DuplicateBoardGroupRequest> {
    data: {
        duplicate_group: SelectBoardGroupReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface DuplicateBoardGroupFullResponseOK {
    data: {
        duplicate_group: BoardGroupReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface UpdateBoardGroupResponseOK<S extends UpdateBoardGroupRequest> {
    data: {
        update_group: SelectBoardGroupReturnType<S['fields']>;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
export interface UpdateBoardGroupFullResponseOK {
    data: {
        update_group: BoardGroupReturnType;
        complexity?: ComplexityReturnType;
    };
    account_id: number;
}
//# sourceMappingURL=board.d.ts.map